% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LeveneTest.R
\name{Levene.Test}
\alias{Levene.Test}
\title{Levene's Test for Homogeneity of Variances (Manual Implementation)}
\usage{
Levene.Test(formula, data, alpha = 0.05, center = "median")
}
\arguments{
\item{formula}{A formula of the form \code{y ~ group}, where \code{y} is numeric and \code{group} is a factor.}

\item{data}{A data frame containing the variables in the formula.}

\item{alpha}{Significance level (default is 0.05).}

\item{center}{Character string: use \code{"median"} (default) or \code{"mean"} as the center for deviations.}
}
\value{
An object of class \code{"homocedasticidad"}, containing:
\describe{
  \item{Statistic}{F statistic of the Levene test.}
  \item{df}{Degrees of freedom (between and within groups).}
  \item{p_value}{The p-value for the test.}
  \item{Decision}{\code{"Homoscedastic"} or \code{"Heteroscedastic"} depending on the test result.}
  \item{Method}{A string indicating the method used ("Levene").}
}
}
\description{
Performs Levene's test for equality of variances across groups using a formula interface.
This test evaluates the null hypothesis that the variances are equal across groups,
and is commonly used as a preliminary test before ANOVA or other parametric analyses.
}
\details{
Levene’s test is based on an analysis of variance (ANOVA) applied to the absolute deviations
from each group’s center (either the mean or, more robustly, the median).
It is less sensitive to departures from normality than Bartlett’s test.

Advantages:
- Robust to non-normality, especially when using the median.
- Suitable for equal or unequal sample sizes across groups.
- Widely used in practice for checking homoscedasticity.

Disadvantages:
- Less powerful than parametric alternatives under strict normality.
}
\examples{
data(d_e, package = "Analitica")
res <- Levene.Test(Sueldo_actual ~ labor, data = d_e)
summary(res)

}
\references{
Levene, H. (1960). "Robust Tests for Equality of Variances." In Contributions to Probability and Statistics: Essays in Honor of Harold Hotelling (pp. 278–292). Stanford University Press.
}
